@@ -19,7 +19,7 @@ class Bugs_DBDataObject_Bugdb_Comments extends DB_DataObject
     var $active;                          // bool
 
     /* Static get */
-    function staticGet($k,$v=NULL) { return DB_DataObject::staticGet('Bugs_DBDataObject_Bugdb_Comments',$k,$v); }
+    static function staticGet($k,$v=NULL) { return DB_DataObject::staticGet('Bugs_DBDataObject_Bugdb_Comments',$k,$v); }
 
     /* the code above is auto generated do not remove the tag below */
     ###END_AUTOCODE
