@@ -17,7 +17,7 @@ class Bugs_DBDataObject_Bugdb_roadmap extends DB_DataObject
     var $description;                     // blob(65535)  not_null blob
 
     /* Static get */
-    function staticGet($k,$v=NULL) { return DB_DataObject::staticGet('Bugs_DBDataObject_Bugdb_roadmap',$k,$v); }
+    static function staticGet($k,$v=NULL) { return DB_DataObject::staticGet('Bugs_DBDataObject_Bugdb_roadmap',$k,$v); }
 
     /* the code above is auto generated do not remove the tag below */
     ###END_AUTOCODE
