@@ -14,7 +14,7 @@ class Bugs_DBDataObject_Bugdb_roadmap_link extends DB_DataObject
     var $roadmap_id;                      // int(8)  not_null primary_key
 
     /* Static get */
-    function staticGet($k,$v=NULL) { return DB_DataObject::staticGet('Bugs_DBDataObject_Bugdb_roadmap_link',$k,$v); }
+    static function staticGet($k,$v=NULL) { return DB_DataObject::staticGet('Bugs_DBDataObject_Bugdb_roadmap_link',$k,$v); }
 
     /* the code above is auto generated do not remove the tag below */
     ###END_AUTOCODE
