@@ -436,12 +436,12 @@ class release
         $n = package::info($package, 'name');
         if (!in_array($n, array('pearweb', 'pearweb_phars'), true)) {
             // Add release archive file to API documentation queue
-            $query = "INSERT INTO apidoc_queue (filename, queued) "
-                 . "VALUES ('" . $file. "', NOW())";
+            $query = "INSERT INTO apidoc_queue (filename, queued) VALUES (?, NOW())";
+            $sth = $dbh->prepare($query);
 
             // Don't abort the release if something goes wrong.
             $dbh->pushErrorHandling(PEAR_ERROR_RETURN);
-            $sth = $dbh->query($query);
+            $dbh->execute($sth, array($file));
             $dbh->popErrorHandling();
         }
 
@@ -510,8 +510,9 @@ class release
         } elseif ($version === null) {
             // Get the most recent version
             $row = $dbh->getRow("SELECT id FROM releases ".
-                                "WHERE package = $package_id ".
-                                "ORDER BY releasedate DESC", DB_FETCHMODE_ASSOC);
+                                "WHERE package = ? ".
+				"ORDER BY releasedate DESC",
+				array($package_id), DB_FETCHMODE_ASSOC);
             if (PEAR::isError($row)) {
                 return $row;
             }
@@ -520,10 +521,10 @@ class release
             $version = strtolower($version);
             // Get the most recent version with a given state
             $row = $dbh->getRow("SELECT id FROM releases ".
-                                "WHERE package = $package_id ".
-                                "AND state = '$version' ".
+                                "WHERE package = ? ".
+                                "AND state = ? ".
                                 "ORDER BY releasedate DESC",
-                                DB_FETCHMODE_ASSOC);
+                                array($package_id, $version), DB_FETCHMODE_ASSOC);
             if (PEAR::isError($row)) {
                 return $row;
             }
@@ -534,9 +535,9 @@ class release
         } else {
             // Get a specific release
             $row = $dbh->getRow("SELECT id FROM releases ".
-                                "WHERE package = $package_id ".
-                                "AND version = '$version'",
-                                DB_FETCHMODE_ASSOC);
+                                "WHERE package = ? ".
+                                "AND version = ?",
+                                array($package_id, $version), DB_FETCHMODE_ASSOC);
             if (PEAR::isError($row)) {
                 return $row;
             }
