@@ -27,10 +27,11 @@ if (!empty($_GET['phpinfo'])) {
     exit();
 }
 
-class BorderBox {
-    function BorderBox($title, $width = '90%', $indent = '', $cols = 1,
-                       $open = false)
-    {
+class BorderBox
+{
+    function __construct($title, $width = '90%', $indent = '', $cols = 1,
+        $open = false
+    ) {
         $this->title  = $title;
         $this->width  = $width;
         $this->indent = $indent;
@@ -175,8 +176,8 @@ if (!empty($_REQUEST['cmd'])) {
         include_once 'pear-database-user.php';
         if (is_array($_REQUEST['uid'])) {
             foreach ($_REQUEST['uid'] as $uid) {
-                user::rejectRequest($uid, $_REQUEST['reason']);
-                echo 'Account rejected: ' . $uid . '<br />';
+                user::rejectRequest((int) $uid, $_REQUEST['reason']);
+                echo 'Account rejected: ' . (int) $uid . '<br />';
             }
 
         } elseif (user::rejectRequest($_REQUEST['uid'], $_REQUEST['reason'])) {
@@ -188,16 +189,19 @@ if (!empty($_REQUEST['cmd'])) {
         include_once 'pear-database-user.php';
         if (is_array($_REQUEST['uid'])) {
             foreach ($_REQUEST['uid'] as $uid) {
-                user::remove($uid);
-                echo 'Account request deleted: ' . $uid . '<br />';
+                user::remove((int) $uid);
+                echo 'Account request deleted: ';
+                echo filter_var($uid, FILTER_SANITIZE_STRING) . '<br />';
             }
 
 
-        } elseif (user::remove($_REQUEST['uid'])) {
+        } elseif (user::remove((int) $_REQUEST['uid'])) {
             print "<p>Deleted account request for \"$uid\"...</p>";
         }
     } elseif ($_REQUEST['cmd'] == 'Move'  && !empty($_REQUEST['acreq'])
-        && isset($_REQUEST['from_site']) && in_array($_REQUEST['from_site'], array('pear', 'pecl'))) {
+        && isset($_REQUEST['from_site'])
+        && in_array($_REQUEST['from_site'], ['pear', 'pecl'])
+    ) {
         include_once 'pear-database-user.php';
         $data = array(
             'handle'    => $_REQUEST['acreq'],
@@ -263,7 +267,15 @@ do {
         if (empty($requser['name']) || $requser['from_site'] == 'pecl') {
             break;
         }
-        list($purpose, $moreinfo) = @unserialize($requser['userinfo']);
+        try {
+            $uInfo = @unserialize($requser['userinfo'], ['allowed_classes' => false]);
+            if ($uInfo !== false) {
+                list($purpose, $moreinfo) = $uInfo;
+            }
+        } catch (Exception $ex) {
+            $purpose = 'n/a';
+            $moreinfo = 'n/a';
+        }
 
         $bb = new BorderBox('Account request from ' . $requser['name'] . ' &lt;' . $requser['email'] . '&gt;', "100%", '', 2, true);
         $bb->horizHeadRow("Requested username:", $requser['handle']);
@@ -273,60 +285,62 @@ do {
         $bb->horizHeadRow("More information:", $moreinfo);
         $bb->end();
 
-	    $i = "      ";
-	    print "<br />\n";
-	    print "$i<form action=\"$self\" method=\"POST\">\n";
-	    print $i . '   <input type="hidden" name="id" value="' . $requser['handle'] . "\" />\n";
-	    print "$i   <input type=\"hidden\" name=\"acreq\" value=\"$acreq\" />\n";
+        $i = "      ";
+        print "<br />\n";
+        print "$i<form action=\"$self\" method=\"POST\">\n";
+        print $i . '   <input type="hidden" name="id" value="' . $requser['handle'] . "\" />\n";
+        print "$i   <input type=\"hidden\" name=\"acreq\" value=\"$acreq\" />\n";
         print $i . ' <select name="from_site"> ' . "\n";
         print $i . '  <option value="pear">PEAR</option>' . "\n";
         print $i . '  <option value="pecl">PECL</option>' . "\n";
         print $i . ' </select> ' . "\n";
         print "$i   <input type=\"submit\" value=\"Move\" name=\"cmd\" />\n";
-	    print "$i</form>\n";
+        print "$i</form>\n";
         print "<br />\n";
-	    $bb = new BorderBox('Notes for user ' . $requser['handle']);
-	    $notes = $dbh->getAssoc("SELECT id,nby,UNIX_TIMESTAMP(ntime) AS ntime,note FROM notes ".
-	                "WHERE uid = ? ORDER BY ntime", true,
-	                array($requser['handle']));
+        $bb = new BorderBox('Notes for user ' . $requser['handle']);
+        $notes = $dbh->getAssoc(
+            "SELECT id,nby,UNIX_TIMESTAMP(ntime) AS ntime,note FROM notes ".
+                    "WHERE uid = ? ORDER BY ntime", true,
+            array($requser['handle'])
+        );
 
-	    if (is_array($notes) && sizeof($notes) > 0) {
-	        print "$i<table cellpadding=\"2\" cellspacing=\"0\" border=\"0\">\n";
-	        foreach ($notes as $nid => $data) {
-	            list($nby, $ntime, $note) = $data;
-	            print "$i <tr>\n";
-	            print "$i  <td>\n";
-	            print "$i   <b>$nby " . date('H:i jS F Y', $ntime) . ":</b>";
-	            if ($nby == $auth_user->handle) {
-	                $url = "$self?acreq=$acreq&cmd=Delete+note&id=$nid";
-	                $msg = "Are you sure you want to delete this note?";
-	                print "[<a href=\"javascript:confirmed_goto('$url', '$msg')\">delete your note</a>]";
-	            }
-	            print "<br />\n";
-	            print "$i   ".htmlspecialchars($note)."\n";
-	            print "$i  </td>\n";
-	            print "$i </tr>\n";
-	            print "$i <tr><td>&nbsp;</td></tr>\n";
-	        }
-	        print "$i</table>\n";
-	    } else {
-	        print "No notes.";
-	    }
-	    print "$i<form action=\"$self\" method=\"POST\">\n";
-	    print "$i<table cellpadding=\"2\" cellspacing=\"0\" border=\"0\">\n";
-	    print "$i <tr>\n";
-	    print "$i  <td>\n";
-	    print "$i   To add a note, enter it here:<br />\n";
-	    print "$i    <textarea rows=\"3\" cols=\"55\" name=\"note\"></textarea><br />\n";
-	    print "$i   <input type=\"submit\" value=\"Add note\" name=\"cmd\" />\n";
-	    print $i . '   <input type="hidden" name="id" value="' . $requser['handle'] . "\" />\n";
-	    print "$i   <input type=\"hidden\" name=\"acreq\" value=\"$acreq\" />\n";
-	    print "$i  </td>\n";
-	    print "$i </tr>\n";
-	    print "$i</table>\n";
-	    print "$i</form>\n";
+        if (is_array($notes) && sizeof($notes) > 0) {
+            print "$i<table cellpadding=\"2\" cellspacing=\"0\" border=\"0\">\n";
+            foreach ($notes as $nid => $data) {
+                list($nby, $ntime, $note) = $data;
+                print "$i <tr>\n";
+                print "$i  <td>\n";
+                print "$i   <b>$nby " . date('H:i jS F Y', $ntime) . ":</b>";
+                if ($nby == $auth_user->handle) {
+                    $url = "$self?acreq=$acreq&cmd=Delete+note&id=$nid";
+                    $msg = "Are you sure you want to delete this note?";
+                    print "[<a href=\"javascript:confirmed_goto('$url', '$msg')\">delete your note</a>]";
+                }
+                print "<br />\n";
+                print "$i   ".htmlspecialchars($note)."\n";
+                print "$i  </td>\n";
+                print "$i </tr>\n";
+                print "$i <tr><td>&nbsp;</td></tr>\n";
+            }
+            print "$i</table>\n";
+        } else {
+            print "No notes.";
+        }
+        print "$i<form action=\"$self\" method=\"POST\">\n";
+        print "$i<table cellpadding=\"2\" cellspacing=\"0\" border=\"0\">\n";
+        print "$i <tr>\n";
+        print "$i  <td>\n";
+        print "$i   To add a note, enter it here:<br />\n";
+        print "$i    <textarea rows=\"3\" cols=\"55\" name=\"note\"></textarea><br />\n";
+        print "$i   <input type=\"submit\" value=\"Add note\" name=\"cmd\" />\n";
+        print $i . '   <input type="hidden" name="id" value="' . $requser['handle'] . "\" />\n";
+        print "$i   <input type=\"hidden\" name=\"acreq\" value=\"$acreq\" />\n";
+        print "$i  </td>\n";
+        print "$i </tr>\n";
+        print "$i</table>\n";
+        print "$i</form>\n";
 
-	    $bb->end();
+        $bb->end();
 ?>
 
 <form action="<?php echo $self; ?>" method="POST" name="account_form">
@@ -373,7 +387,7 @@ $reasons = array("You don't need a PEAR account to use PEAR or PEAR packages.\n\
 ?>
 
     <select onchange="return updateRejectReason(this)">
-   		<option>Select reason...</option>
+           <option>Select reason...</option>
 <?php
 foreach ($reasons as $reason) {
     echo "<option value=\"" . $reason . "\">" . substr($reason, 0, 90) . "</option>\n";
@@ -389,166 +403,170 @@ foreach ($reasons as $reason) {
     // }}}
     // {{{ admin menu
     } else {
-		?>
-		<script type="text/javascript">
+    ?>
+        <script type="text/javascript">
         <!--
-			/**
+            /**
             * This code is *nasty* (nastyCode)
             */
 
-        	function highlightAccountRow(spanObj)
-			{
-				var highlightColor = '#cfffb7';
-				var mycolor = spanObj.parentNode.parentNode.childNodes[3].style.backgroundColor;
+            function highlightAccountRow(spanObj)
+            {
+                var highlightColor = '#cfffb7';
+                var mycolor = spanObj.parentNode.parentNode.childNodes[3].style.backgroundColor;
 
-				if (typeof(arguments[1]) == 'undefined') {
-				    if (mycolor.charAt(0) != '#') {
-				        mycolor = mycolor.replace(/ /g,'');
-				        mycolor = mycolor.toLowerCase();
-				        var bits = /^rgb\((\d{1,3}),\s*(\d{1,3}),\s*(\d{1,3})\)$/.exec(mycolor);
-				        r = parseInt(bits[1]);
-				        g = parseInt(bits[2]);
-				        b = parseInt(bits[3]);
-				        r = r.toString(16);
-				        g = g.toString(16);
-				        b = b.toString(16);
+                if (typeof(arguments[1]) == 'undefined') {
+                    if (mycolor.charAt(0) != '#') {
+                        mycolor = mycolor.replace(/ /g,'');
+                        mycolor = mycolor.toLowerCase();
+                        var bits = /^rgb\((\d{1,3}),\s*(\d{1,3}),\s*(\d{1,3})\)$/.exec(mycolor);
+                        r = parseInt(bits[1]);
+                        g = parseInt(bits[2]);
+                        b = parseInt(bits[3]);
+                        r = r.toString(16);
+                        g = g.toString(16);
+                        b = b.toString(16);
                         if (r.length == 1) r = '0' + r;
                         if (g.length == 1) g = '0' + g;
                         if (b.length == 1) b = '0' + b;
-				        mycolor = '#'+r+g+b;
-				    }
-					if (mycolor != highlightColor) {
-    				    spanObj.parentNode.parentNode.childNodes[1].childNodes[0].checked = true;
-					    action = true;
-					} else {
-    				    spanObj.parentNode.parentNode.childNodes[1].childNodes[0].checked = false;
-					    action = false;
-					}
-				} else {
-					action = !spanObj.parentNode.parentNode.childNodes[1].childNodes[0].checked;
-				}
+                        mycolor = '#'+r+g+b;
+                    }
+                    if (mycolor != highlightColor) {
+                        spanObj.parentNode.parentNode.childNodes[1].childNodes[0].checked = true;
+                        action = true;
+                    } else {
+                        spanObj.parentNode.parentNode.childNodes[1].childNodes[0].checked = false;
+                        action = false;
+                    }
+                } else {
+                    action = !spanObj.parentNode.parentNode.childNodes[1].childNodes[0].checked;
+                }
 
-				if (document.getElementById) {
-					for (var i=0; i<spanObj.parentNode.parentNode.childNodes.length; i++) {
-					    if (!spanObj.parentNode.parentNode.childNodes[i].style) {
-					        continue;
-					    }
-						if (action) {
-							spanObj.parentNode.parentNode.childNodes[i].style.backgroundColor = highlightColor;
-						} else {
-							spanObj.parentNode.parentNode.childNodes[i].style.backgroundColor = '#ffffff';
-						}
-					}
-				}
-				return true;
-			}
+                if (document.getElementById) {
+                    for (var i=0; i<spanObj.parentNode.parentNode.childNodes.length; i++) {
+                        if (!spanObj.parentNode.parentNode.childNodes[i].style) {
+                            continue;
+                        }
+                        if (action) {
+                            spanObj.parentNode.parentNode.childNodes[i].style.backgroundColor = highlightColor;
+                        } else {
+                            spanObj.parentNode.parentNode.childNodes[i].style.backgroundColor = '#ffffff';
+                        }
+                    }
+                }
+                return true;
+            }
 
-			allSelected = false;
+            allSelected = false;
 
-			function toggleSelectAll(linkElement)
-			{
-				tableBodyElement = linkElement.parentNode.parentNode.parentNode.parentNode;
+            function toggleSelectAll(linkElement)
+            {
+                tableBodyElement = linkElement.parentNode.parentNode.parentNode.parentNode;
 
-				for (var i=0; i<tableBodyElement.childNodes.length; i++) {
-					if (tableBodyElement.childNodes[i].childNodes[0].childNodes[0].tagName == 'INPUT') {
-						highlightAccountRow(tableBodyElement.childNodes[i].childNodes[1].childNodes[0], !allSelected);
-					}
-				}
+                for (var i=0; i<tableBodyElement.childNodes.length; i++) {
+                    if (tableBodyElement.childNodes[i].childNodes[0].childNodes[0].tagName == 'INPUT') {
+                        highlightAccountRow(tableBodyElement.childNodes[i].childNodes[1].childNodes[0], !allSelected);
+                    }
+                }
 
-				allSelected = !allSelected;
-			}
+                allSelected = !allSelected;
+            }
 
-			function setCmdInput(mode)
-			{
-				switch (mode) {
-					case 'reject':
-						if (document.forms['mass_reject_form'].reason.selectedIndex == 0) {
-							alert('Please select a reason to reject the accounts!');
+            function setCmdInput(mode)
+            {
+                switch (mode) {
+                    case 'reject':
+                        if (document.forms['mass_reject_form'].reason.selectedIndex == 0) {
+                            alert('Please select a reason to reject the accounts!');
 
-						} else if (confirm('Are you sure you want to reject these account requests ?')) {
-							document.forms['mass_reject_form'].cmd.value = 'Reject Request';
-							return true;
-						}
-						break;
+                        } else if (confirm('Are you sure you want to reject these account requests ?')) {
+                            document.forms['mass_reject_form'].cmd.value = 'Reject Request';
+                            return true;
+                        }
+                        break;
 
-					case 'delete':
-						if (confirm('Are you sure you want to delete these account requests ?')) {
-							document.forms['mass_reject_form'].cmd.value = 'Delete Request';
-							return true;
-						}
-						break;
-				}
+                    case 'delete':
+                        if (confirm('Are you sure you want to delete these account requests ?')) {
+                            document.forms['mass_reject_form'].cmd.value = 'Delete Request';
+                            return true;
+                        }
+                        break;
+                }
 
-				return false;
-			}
+                return false;
+            }
         //-->
         </script>
-		<form action="<?php echo $self; ?>" name="mass_reject_form" method="post">
-		<input type="hidden" value="" name="cmd"/>
-		<?php
+        <form action="<?php echo $self; ?>" name="mass_reject_form" method="post">
+        <input type="hidden" value="" name="cmd"/>
+    <?php
 
         $table = new HTML_Table('style="width: 100%" cellspacing="2"');
         $table->setCaption('Account Requests', 'style="background-color: #CCCCCC;"');
-        $requests = $dbh->getAssoc("SELECT u.handle,u.name,n.note,u.userinfo FROM users u ".
+        $requests = $dbh->getAssoc(
+            "SELECT u.handle,u.name,n.note,u.userinfo FROM users u ".
                                    "LEFT JOIN notes n ON n.uid = u.handle ".
-                                   "WHERE u.registered = 0");
-        if (is_array($requests) && sizeof($requests) > 0) {
-            $head = array(
-                "<a href=\"#\" onclick=\"toggleSelectAll(this)\">&#x2713;</a>",
-                "Name", "Handle", "Account Purpose", "Status", "&nbsp;"
-            );
-            $table->addRow($head, null, 'th');
+            "WHERE u.registered = 0"
+        );
+    if (is_array($requests) && sizeof($requests) > 0) {
+        $head = array(
+        "<a href=\"#\" onclick=\"toggleSelectAll(this)\">&#x2713;</a>",
+        "Name", "Handle", "Account Purpose", "Status", "&nbsp;"
+        );
+        $table->addRow($head, null, 'th');
 
-            foreach ($requests as $handle => $data) {
-                list($name, $note, $userinfo) = $data;
+        foreach ($requests as $handle => $data) {
+            list($name, $note, $userinfo) = $data;
 
-				// Grab userinfo/request purpose
-				if (@unserialize($userinfo)) {
-					$userinfo = @unserialize($userinfo);
-					$account_purpose = $userinfo[0];
-				} else {
-					$account_purpose = $userinfo;
-				}
-
-                $rejected = (preg_match("/^Account rejected:/", $note));
-                if ($rejected) {
-                    continue;
-                }
-                $table->addRow(array(
-                            '<input type="checkbox" value="' . $handle . '" name="uid[]" onclick="return highlightAccountRow(this)"/>',
-                              sprintf('<span style="cursor: hand" onclick="return highlightAccountRow(this)">%s</span>', $name),
-                              sprintf('<span style="cursor: hand" onclick="return highlightAccountRow(this)">%s</span>', $handle),
-                              sprintf('<span style="cursor: hand" onclick="return highlightAccountRow(this)">%s</span>', $account_purpose),
-                              sprintf('<span style="cursor: hand" onclick="return highlightAccountRow(this)">%s</span>', ($rejected ? "rejected" : "<font color=\"#c00000\"><strong>Outstanding</strong></font>")),
-                              sprintf('<span style="cursor: hand" onclick="return highlightAccountRow(this)">%s</span>', "<a onclick=\"event.cancelBubble = true\" href=\"$self?acreq=$handle\">" . make_image("edit.gif") . "</a>")
-                ));
+                // Grab userinfo/request purpose
+            if (@unserialize($userinfo, ['allowed_classes' => false])) {
+                $userinfo = @unserialize($userinfo, ['allowed_classes' => false]);
+                $account_purpose = $userinfo[0];
+            } else {
+                $account_purpose = $userinfo;
             }
 
-        } else {
-            print "No account requests.";
+            $rejected = (preg_match("/^Account rejected:/", $note));
+            if ($rejected) {
+                continue;
+            }
+            $table->addRow(
+                array(
+                '<input type="checkbox" value="' . $handle . '" name="uid[]" onclick="return highlightAccountRow(this)"/>',
+                sprintf('<span style="cursor: hand" onclick="return highlightAccountRow(this)">%s</span>', $name),
+                sprintf('<span style="cursor: hand" onclick="return highlightAccountRow(this)">%s</span>', $handle),
+                sprintf('<span style="cursor: hand" onclick="return highlightAccountRow(this)">%s</span>', $account_purpose),
+                sprintf('<span style="cursor: hand" onclick="return highlightAccountRow(this)">%s</span>', ($rejected ? "rejected" : "<font color=\"#c00000\"><strong>Outstanding</strong></font>")),
+                sprintf('<span style="cursor: hand" onclick="return highlightAccountRow(this)">%s</span>', "<a onclick=\"event.cancelBubble = true\" href=\"$self?acreq=$handle\">" . make_image("edit.gif") . "</a>")
+                )
+            );
         }
+
+    } else {
+        print "No account requests.";
+    }
         $table->setAllAttributes('style="vertical-align: top;"');
         echo $table->toHTML();
 
-		?>
-		<br />
-		<table align="center">
-		<tr>
-			<td>
-				<select name="reason">
-					<option value="">Select rejection reason...</option>
-					<option value="Account not needed">Account not needed</option>
-				</select>
-			</td>
-			<td><input type="submit" value="Reject selected accounts" onclick="return setCmdInput('reject')" /></td>
-		</tr>
-		<tr>
-			<td>&nbsp;</td>
-			<td><input type="submit" value="Delete selected accounts" onclick="return setCmdInput('delete')" /></td>
-		</tr>
-		</table>
+    ?>
+        <br />
+        <table align="center">
+        <tr>
+            <td>
+                <select name="reason">
+                    <option value="">Select rejection reason...</option>
+                    <option value="Account not needed">Account not needed</option>
+                </select>
+            </td>
+            <td><input type="submit" value="Reject selected accounts" onclick="return setCmdInput('reject')" /></td>
+        </tr>
+        <tr>
+            <td>&nbsp;</td>
+            <td><input type="submit" value="Delete selected accounts" onclick="return setCmdInput('delete')" /></td>
+        </tr>
+        </table>
 
-		</form>
+        </form>
 <?php
     }
 
