@@ -6,7 +6,7 @@ if (!isset($_GET['handle'])) {
     exit;
 }
 require 'bugs/pear-bug-accountrequest.php';
-$account = new PEAR_Bug_Accountrequest($_GET['handle']);
+$account = new PEAR_Bug_Accountrequest(filter_var($_GET['handle'], FILTER_SANITIZE_STRING));
 if ($account->pending()) {
     try {
         $account->sendEmail();
@@ -28,4 +28,4 @@ response_header('PEAR :: email re-sent');?>
 The verification email has been sent to your email address.
 </p>
 <?php
-response_footer();
\ No newline at end of file
+response_footer();
